@@ -1109,11 +1109,13 @@ class RepositoryProvider(object):
     def __getModelPathList(self):
         """Return the list of computational models the current cached model repository.
 
-        File name template is: *.cif.gz
+        File name template is:  <modelDirPath>/<source>/*.cif.gz
+                                         -  or -
+                                <modelDirPath>/<hash>/<hash>/*.cif.gz
 
         """
         #
-        for modelType in ["AlphaFold"]:
+        for modelType in ["computed-models"]:
             modelDirPath = os.path.join(self.__topCachePath, modelType)
             pathList = []
             logger.info("Searching for models in path %r", modelDirPath)
@@ -1122,6 +1124,12 @@ class RepositoryProvider(object):
                 logger.info("Using pattern %r", pattern)
                 for pth in glob.iglob(pattern, recursive=True):
                     pathList.append(pth)
+                if not pathList:
+                    pattern = os.path.join(modelDirPath, "*", "*", "*", "*.cif.gz")
+                    logger.info("Using pattern %r", pattern)
+                    for pth in glob.iglob(pattern, recursive=True):
+                        pathList.append(pth)
+
             except Exception as e:
                 logger.exception("Failing search in %r with %s", modelDirPath, str(e))
             #
